# Changelog

All notable changes to this project will be documented in this file.

The format is based on Keep a Changelog,
and this project adheres to Semantic Versioning.

## [0.1.0] - 2026-03-12



### Maintenance

- Initial project setup

- **repo:** Complete OSS setup for renamr

<!-- generated by git-cliff -->
